#
# spec file for package python-venusian
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013-2019 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-venusian
Version:        1.2.0
Release:        2.14
Summary:        A library for deferring decorator actions
License:        SUSE-Repoze AND ZPL-2.1
Group:          Development/Languages/Python
URL:            https://github.com/Pylons/venusian
Source:         https://files.pythonhosted.org/packages/source/v/venusian/venusian-%{version}.tar.gz
Patch:          fix-pylons-sphinx-theme.diff
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module coverage}
BuildRequires:  %{python_module nose-exclude}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
# /SECTION
# SECTION documentation requirements
BuildRequires:  python3-Sphinx
BuildRequires:  python3-pylons-sphinx-themes
# /SECTION
%python_subpackages

%description
Venusian is a library which allows framework authors to defer
decorator actions.  Instead of taking actions when a function (or
class) decorator is executed at import time, you can defer the action
usually taken by the decorator until a separate "scan" phase.

See the "docs" directory of the package or the online documentation at
http://docs.pylonsproject.org/projects/venusian/dev/.

%package doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description doc
This package contains documentation files for %{name}.

%prep
%setup -q -n venusian-%{version}
%patch -p1
rm -rf venusian.egg-info

%build
%python_build
python3 setup.py build_sphinx && rm -v build/sphinx/html/{.buildinfo,objects.inv}

%install
%python_install
%python_expand %fdupes -s %{buildroot}%{$python_sitelib}

%check
%python_expand py.test-%{$python_bin_suffix} -v venusian

%files %{python_files}
%license LICENSE.txt
%doc CHANGES.rst README.rst
%{python_sitelib}/venusian
%{python_sitelib}/venusian-%{version}-py%{python_version}.egg-info

%files %{python_files doc}
%license LICENSE.txt
%doc build/sphinx/html/

%changelog
* Thu Feb  7 2019 hpj@urpla.net
- Update to version 1.2.0 (2019-01-08)
  + Add support for Python 3.7.
  + Drop support for Python 3.3.
- Combine package-doc and package spec
- add fix-pylons-sphinx-theme.diff patch
  to generate docs with the pylons-sphinx-themes package
* Thu Jun 28 2018 mcepl@suse.com
- Clean up SPEC file
- Enable tests and make docs work again
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Fri Jul 14 2017 aloisio@gmx.com
- Update to version 1.1.0
  * Updated to using py.test instead of nosetest, and added
    support for Python 3.4 -> 3.6
  * Make scanning more resilient of metaclasses that return
    proxies for any attribute access.
  * Fix bug where using the same venusian decorator on both a
    class and its methods would cause the method decorations to be
    ignored. See https://github.com/Pylons/venusian/issues/40
  * Drop support for Python 2.6.
  * Drop support for Python 3.2: it is no longer supported by
    current packaging / CI tools.
  * Support loaders that require the module name as argument to
    their get_filename() method. This fixes problems with zipped
    packages on Python 3.
  * Micro-optimization when ignores are used (see
    https://github.com/Pylons/venusian/pull/20).
  * A tox run now combines coverage between Py2 and Py3.
- Split docs and tests into separate package to make the
  latter work
- Converted to single-spec
* Fri Feb  6 2015 hpj@urpla.net
- update to version 1.0
  - Fix an issue under PyPy > 2.0 where attached decorators may not be found.
  - Drop support of Python 2.4 / 2.5 / Jython.
  - Add lift and onlyliftedfrom class decorators to allow for inheritance of
    venusian decorators attached to superclass methods. See the API
    documentation for more information.
  - Fix bug where otherwise undecorated subclass of a superclass that had
    venusian decorators on it would inherit its superclass' decorations.
    Venusian decorators should have never been inherited implicitly. See
    https://github.com/Pylons/venusian/issues/11#issuecomment-4977352
* Wed Dec 18 2013 cfarrell@suse.com
- license update: SUSE-Repoze
  See LICENSE
* Tue Dec 10 2013 p.drouand@gmail.com
- Use tarball from pypi.python.org/ as source
* Tue Dec 10 2013 p.drouand@gmail.com
- Change license to get it SPDX compliant;
  In general, python packages are licensed under BSD derived; the
  most closed license is BSD-2-Clause
* Mon Jul 29 2013 speilicke@suse.com
- Simplify macro usage
* Sun Jul 28 2013 hpj@urpla.net
- version 1.0a8: initial release
